Computer Use tool for screen interaction via Anthropic API or native mode.
Re-exports
pub use actions::ComputerMode;pub use actions::ComputerUseInput;pub use actions::ComputerUseOutput;pub use screen::ComputerUseTool;
Computer Use tool for screen interaction via Anthropic API or native mode.
pub use actions::ComputerMode;pub use actions::ComputerUseInput;pub use actions::ComputerUseOutput;pub use screen::ComputerUseTool;